﻿using System;
using System.Diagnostics;
using CoreAnimation;
using CoreGraphics;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace CustomizedTooltip
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		SFChart chart;

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			chart = new SFChart();
			chart.EdgeInsets = new UIEdgeInsets(20, 10, 10, 10);
			chart.Frame = new CGRect(0, 0, this.View.Frame.Width, this.View.Frame.Height - 30);

			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			chart.PrimaryAxis = primaryAxis;

			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			chart.SecondaryAxis = secondaryAxis;

			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;

			chart.Delegate = new ChartTooltipDelegate();

			SFChartTooltipBehavior behavior = new SFChartTooltipBehavior();
			behavior.BackgroundColor = UIColor.FromRGBA(193.0f / 255.0f, 39.0f / 255.0f, 45.0f / 255.0f, 1.0f);
			behavior.Duration = double.PositiveInfinity;
			chart.AddChartBehavior(behavior);

			this.View.AddSubview(chart);
		}


		public override void ViewWillAppear(bool animated)
		{
			base.ViewWillAppear(animated);
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}

	public class ChartTooltipDelegate : SFChartDelegate
	{
		void TapGesture_Handled(UITapGestureRecognizer tap)
		{
			tap.View.BackgroundColor = UIColor.Green;
		}

		public override void WillShowTooltip(SFChart chart, SFChartTooltip tooltipView)
		{
			UITapGestureRecognizer tapGesture = new UITapGestureRecognizer(TapGesture_Handled);
			tapGesture.NumberOfTapsRequired = 1;

			UITapGestureRecognizer tapGesture1 = new UITapGestureRecognizer(TapGesture_Handled);
			tapGesture1.NumberOfTapsRequired = 1;

			UIView customView = new UIView();
			customView.Frame = new CGRect(0, 0, 80, 40);

			UIImageView imageView = new UIImageView();
			imageView.Frame = new CGRect(0, 0, 40, 40);
			imageView.Image = UIImage.FromBundle("grain.png");
			imageView.UserInteractionEnabled = true;
			imageView.AddGestureRecognizer(tapGesture);

			UILabel xLabel = new UILabel();
			xLabel.Frame = new CGRect(47, 0, 35, 18);
			xLabel.TextColor = UIColor.Orange;
			xLabel.Font = UIFont.FromName("Helvetica", 12f);
			xLabel.Text = tooltipView.DataPoint.XValue.ToString();
			xLabel.UserInteractionEnabled = true;
			xLabel.AddGestureRecognizer(tapGesture1);

			UILabel yLabel = new UILabel();
			yLabel.Frame = new CGRect(47, 20, 35, 18);
			yLabel.TextColor = UIColor.White;
			yLabel.Font = UIFont.FromName("Helvetica", 15f);
			yLabel.Text = tooltipView.Text;

			customView.AddSubview(imageView);
			customView.AddSubview(xLabel);
			customView.AddSubview(yLabel);
			tooltipView.CustomView = customView;
		}
	}

	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray DataPoints;

		public ChartDataModel()
		{

			DataPoints = new NSMutableArray();
			AddDataPointsForChart("2007", 16);
			AddDataPointsForChart("2008", 28);
			AddDataPointsForChart("2009", 38);
			AddDataPointsForChart("2010", 22);
			AddDataPointsForChart("2011", 19);
			AddDataPointsForChart("2012", 35);
			AddDataPointsForChart("2013", 42);
			AddDataPointsForChart("2014", 31);
			AddDataPointsForChart("2015", 34);
		}

		void AddDataPointsForChart(String month, Double value)
		{
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject(month), NSObject.FromObject(value)));
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			SFColumnSeries series = new SFColumnSeries();
			series.EnableTooltip = true;
			return series;
		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
			
		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (int)DataPoints.Count;
		}
	}

}

